@@ -20,29 +20,28 @@
 
 #include "configwizard.h"
 
-#include <QtGui/QLayout>
-#include <QtGui/QLabel>
+#include <QLayout>
+#include <QLabel>
+#include <QStandardPaths>
 
-#include <k3listview.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kstandarddirs.h>
-#include <kconfig.h>
-#include <ktoolinvocation.h>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <KHelpClient>
+#include <KLocalizedString>
 
 #include "texttospeechconfigurationwidget.h"
 #include "phrasebook/initialphrasebookwidget.h"
 #include "wordcompletion/wordcompletion.h"
 #include "wordcompletion/dictionarycreationwizard.h"
 
-ConfigWizard::ConfigWizard(QWidget *parent, KConfig *config)
-    : QWizard(parent), m_config(config)
+ConfigWizard::ConfigWizard(QWidget *parent)
+    : QWizard(parent)
 {
     setWindowTitle(i18n("Initial Configuration - KMouth"));
     initCommandPage();
     initBookPage();
     initCompletion();
-    connect(this, SIGNAL(accepted()), this, SLOT(saveConfig()));
+    connect(this, &QDialog::accepted, this, &ConfigWizard::saveConfig);
 }
 
 ConfigWizard::~ConfigWizard()
@@ -51,14 +50,14 @@ ConfigWizard::~ConfigWizard()
 
 void ConfigWizard::initCommandPage()
 {
-    KConfigGroup cg(m_config, QLatin1String("TTS System"));
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("TTS System"));
     bool displayCommand = false;
     if (!cg.hasKey("StdIn"))   displayCommand = true;
     if (!cg.hasKey("Codec"))   displayCommand = true;
 
     if (displayCommand) {
         commandWidget = new TextToSpeechConfigurationWidget(this, "ttsPage");
-        commandWidget->readOptions(m_config, QLatin1String("TTS System"));
+        commandWidget->readOptions(QStringLiteral("TTS System"));
         commandWidget->setTitle(i18n("Text-to-Speech Configuration"));
         addPage(commandWidget);
         commandWidget->setFinalPage(true);
@@ -68,7 +67,7 @@ void ConfigWizard::initCommandPage()
 
 void ConfigWizard::initBookPage()
 {
-    QString standardBook = KGlobal::dirs()->findResource("appdata", QLatin1String("standard.phrasebook"));
+    QString standardBook = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("standard.phrasebook"));
     bool displayBook = (standardBook.isNull() || standardBook.isEmpty());
 
     if (displayBook) {
@@ -85,12 +84,12 @@ void ConfigWizard::initBookPage()
 void ConfigWizard::initCompletion()
 {
     if (!WordCompletion::isConfigured()) {
-        QString dictionaryFile = KGlobal::dirs()->findResource("appdata", QLatin1String("dictionary.txt"));
+        QString dictionaryFile = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("dictionary.txt"));
         QFile file(dictionaryFile);
         if (file.exists()) {
             // If there is a word completion dictionary but no entry in the
             // configuration file, we need to add it there.
-            KConfigGroup cg(m_config , "Dictionary 0");
+            KConfigGroup cg(KSharedConfig::openConfig() , "Dictionary 0");
             cg.writeEntry("Filename", "dictionary.txt");
             cg.writeEntry("Name",     "Default");
             cg.writeEntry("Language", QString());
@@ -98,7 +97,7 @@ void ConfigWizard::initCompletion()
         }
     }
 
-    if (m_config->hasGroup("Completion")) {
+    if (KSharedConfig::openConfig()->hasGroup("Completion")) {
         completionWidget = 0;
         return;
     }
@@ -121,14 +120,14 @@ void ConfigWizard::saveConfig()
 {
     if (commandWidget != 0) {
         commandWidget->ok();
-        commandWidget->saveOptions(m_config, QLatin1String("TTS System"));
+        commandWidget->saveOptions(QStringLiteral("TTS System"));
     }
 
     if (bookWidget != 0)
         bookWidget->createBook();
 
     if (completionWidget != 0)
-        completionWidget->ok(m_config);
+        completionWidget->ok();
 }
 
 bool ConfigWizard::requestConfiguration()
@@ -146,7 +145,7 @@ bool ConfigWizard::configurationNeeded()
 
 void ConfigWizard::help()
 {
-    KToolInvocation::invokeHelp(QLatin1String("Wizard"));
+    KHelpClient::invokeHelp(QStringLiteral("Wizard"));
 }
 
 #include "configwizard.moc"
