@@ -20,15 +20,12 @@
 
 #include "speech.h"
 
-#include <QtCore/QStack>
-#include <QtCore/QRegExp>
-#include <QtCore/QTextCodec>
-#include <QtCore/QFile>
-#include <QtCore/QHash>
-#include <QtCore/QTextStream>
+#include <QHash>
+#include <QRegExp>
+#include <QStack>
+#include <QTextCodec>
+#include <QTextStream>
 
-#include <kdebug.h>
-#include <kdeversion.h>
 #define macroExpander
 #include <kmacroexpander.h>
 
@@ -199,39 +196,38 @@ void Speech::speak(QString command, bool stdIn, const QString &text, const QStri
         command = prepareCommand(command, QLatin1String(encText), filename, language);
 
         // 3. create a new process
-        process << command;
-        connect(&process, SIGNAL(processExited(K3Process*)), this, SLOT(processExited(K3Process*)));
-        connect(&process, SIGNAL(wroteStdin(K3Process*)), this, SLOT(wroteStdin(K3Process*)));
-        connect(&process, SIGNAL(receivedStdout(K3Process*, char*, int)), this, SLOT(receivedStdout(K3Process*, char*, int)));
-        connect(&process, SIGNAL(receivedStderr(K3Process*, char*, int)), this, SLOT(receivedStderr(K3Process*, char*, int)));
+        connect(&m_process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(processExited(int, QProcess::ExitStatus)));
+        //connect(&process, SIGNAL(wroteStdin(K3Process*)), this, SLOT(wroteStdin(K3Process*)));
+        //connect(&process, SIGNAL(receivedStdout(K3Process*, char*, int)), this, SLOT(receivedStdout(K3Process*, char*, int)));
+        //connect(&process, SIGNAL(receivedStderr(K3Process*, char*, int)), this, SLOT(receivedStderr(K3Process*, char*, int)));
 
         // 4. start the process
         if (stdIn) {
-            process.start(K3Process::NotifyOnExit, K3Process::All);
+            m_process.start(command);
             if (encText.size() > 0)
-                process.writeStdin(encText, encText.size());
+                m_process.write(encText, encText.size());
             else
-                process.closeStdin();
+                m_process.close();
         } else
-            process.start(K3Process::NotifyOnExit, K3Process::AllOutput);
+            m_process.start(command);
     }
 }
 
-void Speech::receivedStdout(K3Process *, char *buffer, int buflen)
-{
-    kDebug() << QString::fromLatin1(buffer, buflen) + QLatin1Char('\n');
-}
-void Speech::receivedStderr(K3Process *, char *buffer, int buflen)
-{
-    kDebug() << QString::fromLatin1(buffer, buflen) + QLatin1Char('\n');
-}
+//void Speech::receivedStdout(K3Process *, char *buffer, int buflen)
+//{
+//    kDebug() << QString::fromLatin1(buffer, buflen) + QLatin1Char('\n');
+//}
+//void Speech::receivedStderr(K3Process *, char *buffer, int buflen)
+//{
+//    kDebug() << QString::fromLatin1(buffer, buflen) + QLatin1Char('\n');
+//}
 
-void Speech::wroteStdin(K3Process *)
-{
-    process.closeStdin();
-}
+//void Speech::wroteStdin(K3Process *)
+//{
+//    process.closeStdin();
+//}
 
-void Speech::processExited(K3Process *)
+void Speech::processExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
     delete this;
 }
